@@ -3,13 +3,13 @@ package MooX::ConfigFromFile;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 my %loaded_configs;
 
 sub import
 {
-    my ( undef, %import_options ) = @_;
+    my (undef, %import_options) = @_;
     my $target = caller;
     my @target_isa;
     { no strict 'refs'; @target_isa = @{"${target}::ISA"} };
@@ -23,6 +23,7 @@ sub import
         return if $target->can('_initialize_from_config');
         my $with = $target->can('with');
         $with->('MooX::ConfigFromFile::Role');
+        $import_options{config_hashmergeloaded} and $with->('MooX::ConfigFromFile::Role::HashMergeLoaded');
     };
     $apply_modifiers->();
 
@@ -42,6 +43,7 @@ sub import
 
     my %default_modifiers = (
         config_prefix               => '_build_config_prefix',
+        config_prefixes             => '_build_config_prefixes',
         config_identifier           => '_build_config_identifier',
         config_prefix_map_separator => '_build_config_prefix_map_separator',
         config_extensions           => '_build_config_extensions',
@@ -49,11 +51,11 @@ sub import
         config_files                => '_build_config_files',
     );
 
-    foreach my $opt_key ( keys %default_modifiers )
+    foreach my $opt_key (keys %default_modifiers)
     {
         exists $import_options{$opt_key} or next;
         $around or $around = $target->can('around');
-        $around->( $default_modifiers{$opt_key} => sub { $import_options{$opt_key} } );
+        $around->($default_modifiers{$opt_key} => sub { $import_options{$opt_key} });
     }
 
     return;
@@ -123,10 +125,24 @@ in default initializers for appropriate role attributes:
 
 Default for L<MooX::ConfigFromFile::Role/config_prefix>.
 
+=item C<config_prefixes>
+
+Default for L<MooX::ConfigFromFile::Role/config_prefixes>. Ensure when use
+this flag together with L<MooX::Cmd> to load C<MooX::ConfigFromFile> before
+C<MooX::Cmd>.
+
 =item C<config_prefix_map_separator>
 
 Default for L<MooX::ConfigFromFile::Role/config_prefix_map_separator>.
 
+  package Foo;
+
+  # apply role MooX::ConfigFromFile::Role and override default for
+  # attribute config_prefix_map_separator
+  use MooX::ConfigFromFile config_prefix_map_separator => "~";
+
+  ...
+
 =item C<config_extensions>
 
 Default for L<MooX::ConfigFromFile::Role/config_extensions>.
@@ -137,6 +153,12 @@ Default for L<MooX::ConfigFromFile::Role/config_dirs>.
 Same warning regarding modifying this attribute applies here:
 Possible, but use with caution!
 
+  package Foo;
+
+  use MooX::ConfigFromFile config_dirs => [qw(/opt/foo/etc /home/alfred/area/foo/etc)];
+
+  ...
+
 =item C<config_files>
 
 Default for L<MooX::ConfigFromFile::Role/config_files>.
@@ -155,6 +177,19 @@ from applicable modifiers per class (and singletons are per class).
 
 Default for L<MooX::File::ConfigDir/config_identifier>.
 
+  package Foo;
+
+  # apply role MooX::ConfigFromFile::Role and override default for
+  # attribute config_identifier - means to look e.g. in /etc/foo/
+  use MooX::ConfigFromFile config_identifier => "foo";
+
+  ...
+
+=item C<config_hashmergeloaded>
+
+Consumes role L<MooX::ConfigFromFile::Role::HashMergeLoaded> directly after
+L<MooX::ConfigFromFile::Role> has been consumed.
+
 =back
 
 =head1 AUTHOR
@@ -201,7 +236,7 @@ L<http://search.cpan.org/dist/MooX-ConfigFromFile/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013-2015 Jens Rehsack.
+Copyright 2013-2017 Jens Rehsack.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
